{# The :autogenerated: tag is picked up by breadcrumbs.html to suppress "Edit on Github" link #}
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

{{ fullname }} module
{% for item in range(7 + fullname|length) -%}={%- endfor %}

.. currentmodule:: {{ fullname }}

.. automodule:: {{ fullname }}
    :members:
    :undoc-members:
    :show-inheritance:
    :member-order: bysource
